| corgram | R Documentation |
corgram calculates the values of a correlogram (autocorrelation
function or ACF) and plots it.
corgram(
y,
wt = 1,
maxlag = NULL,
partial = FALSE,
add = FALSE,
lty = 1,
xlim = NULL,
ylim = NULL,
xlab = NULL,
ylab = NULL,
main = NULL,
...
)
y |
A time series vector. |
wt |
Indicator vector with zeros for values to be ignored. |
maxlag |
Maximum number of lags for which the correlation is to be calculated. |
partial |
If TRUE, the partial autocorrelation function (PACF) is plotted. |
add |
If TRUE, adds a new correlogram to an existing plot. |
lty |
Plotting parameters |
xlim |
Plotting parameters |
ylim |
Plotting parameters |
xlab |
Plotting parameters |
ylab |
Plotting parameters |
main |
Plotting parameters |
... |
Plotting parameters |
corgram returns a two-column matrix containing the (partial)
correlogram coordinates.
J.K. Lindsey
y <- rnorm(100)
corgram(y)
corgram(y, partial=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.